'use strict';

let koa = require('koa');
let app = koa();
let koaRouter = require('koa-router')();
let glob = require("glob");
let path = require("path");
let json = require('koa-json');
let config = require("./util/config");
let koaBody = require('koa-body')({
  "formLimit":"50mb",
  "jsonLimit":"50mb",
  "textLimit":"50mb",
  multipart: true});
let log = require("@dp/log");
let response = require('koa-response');
let KoaStaticServer = require("koa-static");
let render = require('koa-ejs');
let routerConfig = require("./util/router");
let kcors = require("kcors");
let co = require("co");
//定时作业
require("./job/index.js");

app.use(response(function(){}));
//允许跨域
var whiteList = ['http://vcw.51ping.com','http://vcw.dianping.com','http://uno.51ping.com','http://uno.dianping.com','http://uno.dp']
function checkOrigin(ctx){
  var origin = ctx.accept.headers.origin
  if(!whiteList.includes(origin) && origin.indexOf('localhost:')<0){
    return ctx.throw(`${origin} is not a valid origin`)
  }
  return origin
}
app.use(kcors({origin:checkOrigin,credentials: true}));
// 响应为json化
app.use(json());
// 路由
app.use(koaRouter.routes());
// 静态server
app.use(KoaStaticServer('./static/'));



render(app, {
  root: path.join(__dirname, './view/template'),
  layout: false,
  viewExt: 'html',
  cache: true
});

// 外部接口
require('./externalInterface')(koaRouter,koaBody);


// 路由配置
routerConfig.forEach((it)=>{
    // api
    glob("./"+it.key+"/*.js",(err,files) => {
        files.forEach((file) => {
            let key = path.basename(file,".js");
            let generator = require(file);
          koaRouter[it.method](`/${it.key}/${key}`,koaBody,generator);
        });
    });
});
let generator = require('./view/index.js');
koaRouter['all'](`/`,koaBody,generator);
co(function* (){

    //环境变量
    if(config.envPlugin){
        yield require(`./plugin/${config.envPlugin}`);
    }


    if(config.storePlugin){
        //存储初始化
        yield require(`./plugin/${config.storePlugin}`).init();
    }

    app.listen(config.port);
});

log.info(`server:${config.port}`);

