'use strict';

var _stringify = require('babel-runtime/core-js/json/stringify');

var _stringify2 = _interopRequireDefault(_stringify);

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = {
  createConfigValue: function createConfigValue(obj) {
    var that = this;
    if (obj.type === 'string' || obj.type === 'integer' || obj.type === 'boolean' || obj.type === 'number') {
      return obj.consequence;
    } else if (obj.type === 'array' && obj.format) {
      return obj.consequence;
    } else if (obj.type === 'object') {
      var objValue = {};
      (0, _keys2.default)(obj.properties) && (0, _keys2.default)(obj.properties).forEach(function (key) {
        objValue[key] = that.createConfigValue(obj.properties[key]);
      });
      return objValue;
    } else if (obj.type === 'array') {
      var arrValue = [];
      obj.list && obj.list.forEach(function (oneObj) {
        arrValue.push(that.createConfigValue(oneObj));
      });
      return arrValue;
    }
    return obj.consequence;
  },
  createSchemaValue: function createSchemaValue(obj, key) {
    var _this = this;

    return {
      type: obj.type,
      name: key,
      properties: obj.properties && (0, _keys2.default)(obj.properties).map(function (k, index) {
        return _this.createSchemaValue(obj.properties[k], k);
      })
    };
  },
  toPreviewJson: function toPreviewJson(list) {
    var that = this;
    return list && list.map(function (item) {
      item.value = that.createConfigValue(item.schema);
      item.schema = that.createSchemaValue(item.schema);
      item.slots && item.slots.forEach(function (slot) {
        slot.cards = that.toPreviewJson(slot.cards);
      });
      return item;
    });
  },
  toPreviewConfigJson: function toPreviewConfigJson(list) {
    var result = [];
    var that = this;

    list && list.forEach(function (item) {
      var obj = {
        data: that.createConfigValue(item.schema),
        schema: that.createSchemaValue(item.schema),
        children: []
      };
      item.slots && item.slots.forEach(function (slot) {
        var merge = that.toPreviewConfigJson(slot.cards);
        obj.children = obj.children.concat(merge);
      });

      result.push(obj);
    });

    return result;
  },
  checkSchema: function checkSchema(obj, key, required) {
    var that = this;
    var checkOk = true;
    if (obj.type === 'boolean') {
      return true;
    } else if (obj.type === 'string' && (!obj.consequence || obj.consequence.length < 1) && required && required.indexOf(key) > -1) {
      console.warn('checkOk is not: key- ' + key + ' schema- ' + (0, _stringify2.default)(obj) + ' required- ' + required.toString());
      return false;
    } else if ((obj.type === 'integer' || obj.type === 'number') && !obj.consequence && obj.consequence !== 0 && required && required.indexOf(key) > -1) {
      console.warn('checkOk is not: key- ' + key + ' schema- ' + (0, _stringify2.default)(obj) + ' required- ' + required.toString());
      return false;
    } else if (obj.type === 'array' && obj.format === 'components' && (!obj.consequence || obj.consequence.length < 1) && required && required.indexOf(key) > -1) {
      console.warn('checkOk is not: key- ' + key + ' schema- ' + (0, _stringify2.default)(obj) + ' required- ' + required.toString());
      return false;
    } else if (obj.type === 'object') {
      (0, _keys2.default)(obj.properties) && (0, _keys2.default)(obj.properties).forEach(function (key) {
        checkOk = that.checkSchema(obj.properties[key], key, obj.required) && checkOk;
      });
    } else if (obj.type === 'array') {
      obj.list && obj.list.forEach(function (oneObj) {
        checkOk = that.checkSchema(oneObj) && checkOk;
      });
    }
    return checkOk;
  },
  checkModelListJson: function checkModelListJson(list) {
    var checkOk = true;
    var that = this;
    list && list.forEach(function (model) {
      checkOk = that.checkSchema(model.schema) && checkOk;
      if (!checkOk) {
        return;
      }
      model.slots && model.slots.forEach(function (slot) {
        checkOk = that.checkModelListJson(slot.cards) && checkOk;
      });
    });
    return checkOk;
  },
  getOptListAboutDeleteModel: function getOptListAboutDeleteModel(obj, optList) {
    var that = this;
    if (obj.format === 'tab') {
      if (obj.consequence) {
        var opt = {
          'type': 'deleteItemId',
          'data': obj.consequence
        };
        optList.push(opt);
      }
    } else if (obj.type === 'object') {
      (0, _keys2.default)(obj.properties) && (0, _keys2.default)(obj.properties).forEach(function (key) {
        optList.concat(that.getOptListAboutDeleteModel(obj.properties[key], optList));
      });
    } else if (obj.type === 'array' && obj.format !== 'components') {
      obj.list && obj.list.forEach(function (oneObj) {
        optList.concat(that.getOptListAboutDeleteModel(oneObj, optList));
      });
    }
  },
  getOptListAboutDeleteList: function getOptListAboutDeleteList(list) {
    var optList = [];
    var that = this;
    list && list.forEach(function (model) {
      that.getOptListAboutDeleteModel(model.schema, optList);
      model.slots && model.slots.forEach(function (slot) {
        optList.concat(that.getOptListAboutDeleteList(slot.cards));
      });
    });
    return optList;
  },
  clearSchemaData: function clearSchemaData(obj) {
    var that = this;
    if (obj.format === 'tab') {
      obj.consequence = undefined;
    } else if (obj.type === 'object') {
      (0, _keys2.default)(obj.properties) && (0, _keys2.default)(obj.properties).forEach(function (key) {
        that.clearSchemaData(obj.properties[key]);
      });
    } else if (obj.type === 'array' && obj.format !== 'components') {
      obj.list && obj.list.forEach(function (oneObj) {
        that.clearSchemaData(oneObj);
      });
    }
  },
  clearModelListData: function clearModelListData(list) {
    var that = this;
    list && list.forEach(function (model) {
      that.clearSchemaData(model.schema);
      model.slots && model.slots.forEach(function (slot) {
        that.clearModelListData(slot.cards);
      });
    });
  },
  removeConfigBox: function removeConfigBox(versionConfigStr, module) {
    var versionConfig = void 0;
    try {
      versionConfig = JSON.parse(versionConfigStr || "{}");
    } catch (e) {
      versionConfig = {};
    }
    function _walk(config, module) {
      if (config[module.name]) {
        delete config[module.name];
      }
      if (module.slots && module.slots.length) {
        module.slots.forEach(function (slot) {
          slot.cards && slot.cards.length && slot.cards.forEach(function (card) {
            _walk(config, card);
          });
        });
      }
    }
    _walk(versionConfig, module);

    return (0, _stringify2.default)(versionConfig);
  }
};