/**
 * Created by shen on 2017/2/8.
 */
module.exports = {
  createConfigValue: function (obj) {
    var that = this
    if (obj.type === 'string' || obj.type === 'integer' || obj.type === 'boolean' || obj.type === 'number') {
      return obj.consequence
    } else if (obj.type === 'array' && obj.format) {
      // todo 新增多选的类型的话 这里就需要增加 新增的类型
      return obj.consequence
    } else if (obj.type === 'object') {
      let objValue = {}
      Object.keys(obj.properties) && Object.keys(obj.properties).forEach((key) => {
        objValue[key] = that.createConfigValue(obj.properties[key])
      })
      return objValue
    } else if (obj.type === 'array') {
      let arrValue = []
      obj.list && obj.list.forEach((oneObj) => {
        arrValue.push(that.createConfigValue(oneObj))
      })
      return arrValue
    }
    return obj.consequence
  },
  createSchemaValue: function(obj, key){
    return {
      type: obj.type,
      name: key,
      properties: obj.properties && Object.keys(obj.properties).map((k, index)=>{
        return this.createSchemaValue(obj.properties[k], k)
      })
    }
  },
  toPreviewJson: function (list) {
    var that = this
    return list && list.map(item => {
      item.value = that.createConfigValue(item.schema);
      item.schema = that.createSchemaValue(item.schema);
      item.slots && item.slots.forEach(slot => {
        slot.cards = that.toPreviewJson(slot.cards)
      })
      return item
    })
  },
  toPreviewConfigJson: function (list) {
    var result = [];
    var that = this

    list && list.forEach((item)=>{
      var obj = {
        data : that.createConfigValue(item.schema),
        schema: that.createSchemaValue(item.schema),
        children : []
      }
      item.slots && item.slots.forEach(slot => {
        var merge = that.toPreviewConfigJson(slot.cards)
        obj.children = obj.children.concat(merge)
      });

      result.push(obj);
    })


    return result

  },
  checkSchema: function (obj, key, required) {
    var that = this
    var checkOk = true
    if (obj.type === 'boolean') {
      return true
    } else if (obj.type === 'string' && (!obj.consequence || obj.consequence.length < 1) && required && required.indexOf(key) > -1) {
      console.warn(`checkOk is not: key- ${key} schema- ${JSON.stringify(obj)} required- ${required.toString()}`)
      return false
    } else if ((obj.type === 'integer' || obj.type === 'number') && (!obj.consequence && obj.consequence !== 0) && required && required.indexOf(key) > -1) {
      console.warn(`checkOk is not: key- ${key} schema- ${JSON.stringify(obj)} required- ${required.toString()}`)
      return false
    } else if (obj.type === 'array' && obj.format === 'components' && (!obj.consequence || obj.consequence.length < 1) && required && required.indexOf(key) > -1) {
      console.warn(`checkOk is not: key- ${key} schema- ${JSON.stringify(obj)} required- ${required.toString()}`)
      return false
    } else if (obj.type === 'object') {
      Object.keys(obj.properties) && Object.keys(obj.properties).forEach((key) => {
        checkOk = that.checkSchema(obj.properties[key], key, obj.required) && checkOk
      })
    } else if (obj.type === 'array') {
      obj.list && obj.list.forEach((oneObj) => {
        checkOk = that.checkSchema(oneObj) && checkOk
      })
    }
    return checkOk
  },
  checkModelListJson: function (list) {
    var checkOk = true
    var that = this
    list && list.forEach(model => {
      checkOk = that.checkSchema(model.schema) && checkOk
      if (!checkOk) {
        return
      }
      model.slots && model.slots.forEach(slot => {
        checkOk = that.checkModelListJson(slot.cards) && checkOk
      })
    })
    return checkOk
  },
  getOptListAboutDeleteModel: function (obj, optList) {
    var that = this
    if (obj.format === 'tab') {
      if (obj.consequence) {
        var opt = {
          'type': 'deleteItemId',
          'data': obj.consequence
        }
        optList.push(opt)
      }
    } else if (obj.type === 'object') {
      Object.keys(obj.properties) && Object.keys(obj.properties).forEach((key) => {
        optList.concat(that.getOptListAboutDeleteModel(obj.properties[key], optList))
      })
    } else if (obj.type === 'array' && obj.format !== 'components') {
      obj.list && obj.list.forEach((oneObj) => {
        optList.concat(that.getOptListAboutDeleteModel(oneObj, optList))
      })
    }
  },
  getOptListAboutDeleteList: function (list) {
    var optList = []
    var that = this
    list && list.forEach(model => {
      that.getOptListAboutDeleteModel(model.schema, optList)
      model.slots && model.slots.forEach(slot => {
        optList.concat(that.getOptListAboutDeleteList(slot.cards))
      })
    })
    return optList
  },
  clearSchemaData: function (obj) {
    var that = this
    if (obj.format === 'tab') {
      obj.consequence = undefined
    } else if (obj.type === 'object') {
      Object.keys(obj.properties) && Object.keys(obj.properties).forEach((key) => {
        that.clearSchemaData(obj.properties[key])
      })
    } else if (obj.type === 'array' && obj.format !== 'components') {
      obj.list && obj.list.forEach((oneObj) => {
        that.clearSchemaData(oneObj)
      })
    }
  },
  clearModelListData: function (list) {
    var that = this
    list && list.forEach(model => {
      that.clearSchemaData(model.schema)
      model.slots && model.slots.forEach(slot => {
        that.clearModelListData(slot.cards)
      })
    })
  },
  removeConfigBox(versionConfigStr,module){
        let versionConfig;
        try{
           versionConfig = JSON.parse(versionConfigStr || "{}");
        }catch(e){
          versionConfig = {}
        }
        function _walk(config,module){
            if(config[module.name]){
                delete config[module.name];
            }
            if(module.slots && module.slots.length){
                module.slots.forEach((slot)=>{
                    slot.cards&&slot.cards.length&&slot.cards.forEach((card)=>{
                        _walk(config,card);
                    })
                });
            }
        }
        _walk(versionConfig,module);

        return JSON.stringify(versionConfig);
  }
}
